@@ -73,6 +73,7 @@ class TextCodec(Codec):
         return bytes.decode(c_type.params.get('charset', 'utf-8'))
 
 DEFAULT_REGISTER['text/plain'] = TextCodec
+DEFAULT_REGISTER.alias('text', 'text/plain')
 
 
 class SimpleFormCodec(Codec):
@@ -163,6 +164,7 @@ class SimpleFormCodec(Codec):
         return multi_dict
 
 DEFAULT_REGISTER['application/x-www-form-urlencoded'] = SimpleFormCodec
+DEFAULT_REGISTER.alias('form', 'application/x-www-form-urlencoded')
 
 
 class JSONCodec(Codec):
@@ -197,6 +199,8 @@ class JSONCodec(Codec):
 
 DEFAULT_REGISTER['application/json'] = JSONCodec
 DEFAULT_REGISTER['text/javascript'] = JSONCodec
+DEFAULT_REGISTER.alias('json', 'application/json')
+DEFAULT_REGISTER.alias('json-js', 'text/javascript')
 
 
 class XMLCodec(Codec):
@@ -249,3 +253,4 @@ class XMLCodec(Codec):
         return lxml.objectify.fromstring(bytes)
 
 DEFAULT_REGISTER['application/xml'] = XMLCodec
+DEFAULT_REGISTER.alias('xml', 'application/xml')
